@@ -71,9 +71,16 @@ LIBICAL_ICAL_EXPORT void icalcomponent_remove_property(icalcomponent *component,
 LIBICAL_ICAL_EXPORT int icalcomponent_count_properties(icalcomponent *component,
                                                        icalproperty_kind kind);
 
+/**
+ * Sets the parent icalcomponent for the specified icalproperty @p property.
+ * @since 3.0
+ */
 LIBICAL_ICAL_EXPORT void icalproperty_set_parent(icalproperty *property,
                                                  icalcomponent *component);
 
+/**
+ * Returns the parent @p icalcomponent for the specified @p icalproperty.
+ */
 LIBICAL_ICAL_EXPORT icalcomponent *icalproperty_get_parent(const icalproperty *property);
 
 /* Iterate through the properties */
@@ -183,13 +190,13 @@ LIBICAL_ICAL_EXPORT void icalcomponent_set_dtstart(icalcomponent *comp, struct i
 LIBICAL_ICAL_EXPORT struct icaltimetype icalcomponent_get_dtstart(icalcomponent *comp);
 
 /* For the icalcomponent routines only, dtend and duration are tied
-   together. If you call the set routine for one and the other exists,
-   the routine will calculate the change to the other. That is, if
-   there is a DTEND and you call set_duration, the routine will modify
-   DTEND to be the sum of DTSTART and the duration. If you call a get
-   routine for one and the other exists, the routine will calculate
-   the return value. If you call a set routine and neither exists, the
-   routine will create the apcompriate comperty */
+   together. If you call the get routine for one and the other exists,
+   the routine will calculate the return value. That is, if there is a
+   DTEND and you call get_duration, the routine will return the difference
+   between DTEND and DTSTART. However, if you call a set routine for
+   one and the other exists, no action will be taken and icalerrno will
+   be set to ICAL_MALFORMEDDATA_ERROR. If you call a set routine and
+   neither exists, the routine will create the appropriate property. */
 
 LIBICAL_ICAL_EXPORT struct icaltimetype icalcomponent_get_dtend(icalcomponent *comp);
 
@@ -273,8 +280,25 @@ LIBICAL_ICAL_EXPORT void icalcomponent_foreach_recurrence(icalcomponent *comp,
                                                                             span, void *data),
                                                           void *callback_data);
 
+/**
+ * Normalizes (reorders and sorts the properties) the specified icalcomponent @p comp.
+ * @since 3.0
+ */
 LIBICAL_ICAL_EXPORT void icalcomponent_normalize(icalcomponent *comp);
 
+/*
+ * Computes the datetime corresponding to the specified @p icalproperty and @p icalcomponent.
+ * If the property is a DATE-TIME with a TZID parameter and a corresponding VTIMEZONE
+ * is present in the component, the returned component will already be in the correct
+ * timezone; otherwise the caller is responsible for converting it.
+ *
+ * Call icaltime_is_null_time() on the returned value to detect failures.
+ *
+ * @since 3.0.5
+ */
+LIBICAL_ICAL_EXPORT struct icaltimetype icalproperty_get_datetime_with_component(
+                                                                          icalproperty *prop,
+                                                                          icalcomponent *comp);
 /*************** Type Specific routines ***************/
 
 LIBICAL_ICAL_EXPORT icalcomponent *icalcomponent_new_vcalendar(void);
